@@ -1,5 +1,6 @@
 from math import floor
 from urlparse import parse_qs
+from urllib import urlencode
 from aweber_api.response import AWeberResponse
 
 class AWeberCollection(AWeberResponse):
@@ -49,10 +50,42 @@ class AWeberCollection(AWeberResponse):
         start = page_number * self.page_size
         return { 'ws.start' : start, 'ws.size' : self.page_size }
 
+    def create(self, **kwargs):
+        params = {'ws.op': 'create'}
+        params.update(kwargs)
+
+        response = self.adapter.request('POST', self.url, params,
+            response='headers')
+        if response['status'] != '201':
+            return False
+        new_resource = response['location']
+        self._diff = {}
+        self._data = self.adapter.request('GET', new_resource)
+        return True
+
+    def find(self, **kwargs):
+        params = {'ws.op': 'find'}
+        params.update(kwargs)
+        query_string = urlencode(params)
+        url = '{0.url}?{1}'.format(self, query_string)
+        data = self.adapter.request('GET', url)
+        try:
+            collection = AWeberCollection(url, data, self.adapter)
+        except TypeError:
+            return False
+
+        # collections return total_size_link
+        collection._data['total_size'] = self._get_total_size(url)
+        return collection
+
+    def _get_total_size(self, uri, **kwargs):
+        """Get actual total size number from total_size_link."""
+        total_size_uri = '{0}&ws.show=total_size'.format(uri)
+        return self.adapter.request('GET', total_size_uri)
+
     def _create_entry(self, offset):
         from aweber_api.entry import AWeberEntry
         data = self._entry_data[offset]
-
         url = "{0}/{1}".format(self.url, data['id'])
         self._entries[offset] = AWeberEntry(url, data, self.adapter)
 
